/*jslint browser:true*/
/*global define*/
define([
    "testsuite/qunit",
    "jquery",
    "ep/fn/contextorientation",

    "$ready!"
], function (QUnit, $) {

    "use strict";

    QUnit.module("ep/fn/contextorientation", {
        setup: function () {
            this.elem = $('<div id="test-elem" />').appendTo('body');
            this.context = $('<div id="test-context" />').appendTo('body');

            this.context.css({
                position: "absolute",
                width: 50,
                height: 50
            });
        },

        teardown: function () {
            this.elem.remove();
            this.context.remove();
        }
    });

    QUnit.test("Context and element are in viewport", 5, function () {
        this.context.css({
            top: 200,
            left: 500
        });

        this.elem.css({
            width: 150,
            height: 150
        });

        this.elem.contextOrientation(this.context, "top");

        QUnit.deepEqual(
            this.elem.position(),
            { left: 500, top: 50 },
            "Element is aligned to the top of the context"
        );

        this.elem.contextOrientation(this.context, "left bottom");

        QUnit.deepEqual(
            this.elem.position(),
            { left: 350, top: 250 },
            "Element is aligned to the lower left of the context"
        );

        this.elem.contextOrientation(this.context, "right top");

        QUnit.deepEqual(
            this.elem.position(),
            { left: 550, top: 50 },
            "Element is aligned to the upper right of the context"
        );

        this.elem.contextOrientation(this.context, "center middle");

        QUnit.deepEqual(
            this.elem.position(),
            { left: 450, top: 150 },
            "Element is centered on the context"
        );

        this.elem.contextOrientation(this.context, "center");

        QUnit.deepEqual(
            this.elem.position(),
            { left: 450, top: 200 },
            "Element is centered under the context"
        );
    });

    QUnit.test("Element is outside of the viewport", 2, function () {
        this.context.css({
            top: 10,
            left: 10
        });

        this.elem.css({
            width: 50,
            height: 50
        });

        this.elem.contextOrientation(this.context, "top left");

        QUnit.deepEqual(
            this.elem.position(),
            { left: -40, top: -40 },
            "Element is aligned to the lower right of the context"
        );

        this.context.css({
            top: $(window).height() - 10,
            left: $(window).width() - 10
        });

        this.elem.contextOrientation(this.context, "bottom right");

        QUnit.deepEqual(
            this.elem.position(),
            { left: this.context.position().left + 50, top: this.context.position().top + 50 },
            "Element is aligned to the upper left of the context"
        );
    });

    QUnit.test("Context is an instance of $.Event", 1, function () {
        var evt = new $.Event();

        this.elem.css({
            width: 50,
            height: 50
        });

        evt.pageX = 500;
        evt.pageY = 10;

        this.elem.contextOrientation(evt, "top right");

        QUnit.deepEqual(
            this.elem.position(),
            { left: 500, top: -40 },
            "Element is aligned to the lower right of the context"
        );
    });

});